@@ -15,11 +15,11 @@ Test::Dependencies - Ensure that the dependency listing is complete
 
 =head1 VERSION
 
-Version 0.33
+Version 0.34
 
 =cut
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 =head1 SYNOPSIS
 
@@ -122,7 +122,7 @@ sub _get_modules_used_in_file {
     $code =~ m/^(__DATA__|__END__)$.*/m
         and $code = $`; # strip data and end sections ($`==$PREMATCH)
     $used{$2}++ while $code =~ /^\s*(use|with|extends)\s+['"]?([\w:.]+)['"]?/gm;
-    while ($code =~ m{^\s*use\s+(base|parent)
+    while ($code =~ m{^\s*use\s+(?:base|parent)
                           \s+(?:qw.|(?:(?:['"]|q.|qq.)))([\w\s:]+)}gmx) {
         $used{$_}++ for split ' ', $1;
     }
